@@ -208,7 +208,7 @@ class DataSource:
 
             # Save batch to disk.
             netcdf_filename = path_to_write_to / nd_utils.get_netcdf_filename(batch_idx)
-            batch.to_netcdf(netcdf_filename)
+            batch.to_netcdf(netcdf_filename, engine="h5netcdf")
 
             # Upload if necessary.
             if (
