@@ -21,8 +21,8 @@ def test_sample_spatial_and_temporal_locations_for_examples():  # noqa: D103
 
     gsp = GSPDataSource(
         zarr_path=f"{local_path}/tests/data/gsp/test.zarr",
-        start_dt=datetime(2019, 1, 1),
-        end_dt=datetime(2019, 1, 2),
+        start_dt=datetime(2020, 4, 1),
+        end_dt=datetime(2020, 4, 2),
         history_minutes=30,
         forecast_minutes=60,
         image_size_pixels=64,
@@ -55,7 +55,7 @@ def test_load_yaml_configuration():  # noqa: D103
     filename = local_path / "tests" / "config" / "test.yaml"
     manager.load_yaml_configuration(filename=filename)
     manager.initialise_data_sources()
-    assert len(manager.data_sources) == 6
+    assert len(manager.data_sources) == 7
     assert isinstance(manager.data_source_which_defines_geospatial_locations, GSPDataSource)
 
 
@@ -76,14 +76,14 @@ def test_get_daylight_datetime_index():
     manager.data_source_which_defines_geospatial_locations = sat
     t0_datetimes = manager.get_t0_datetimes_across_all_data_sources(freq="5T")
 
-    # The testing sat_data.zarr has contiguous data from 12:05 to 18:00.
+    # The testing sat_data.zarr has contiguous data from 12:00 to 18:00.
     # nowcasting_datamodule.history_minutes = 30
     # nowcasting_datamodule.forecast_minutes = 60
-    # Daylight ends at 16:20.
-    # So the expected t0_datetimes start at 12:35 (12:05 + 30 minutes)
-    # and end at 15:20 (16:20 - 60 minutes)
+    # Daylight ends after 19:34.
+    # So the expected t0_datetimes start at 12:30 (12:00 + 30 minutes)
+    # and end at 17:00 (18:00 - 60 minutes)
 
-    correct_t0_datetimes = pd.date_range("2019-01-01 12:35", "2019-01-01 15:20", freq="5 min")
+    correct_t0_datetimes = pd.date_range("2020-04-01 12:30", "2020-04-01 17:00", freq="5 min")
     np.testing.assert_array_equal(t0_datetimes, correct_t0_datetimes)
 
 
@@ -92,6 +92,18 @@ def test_batches():
     filename = Path(nowcasting_dataset.__file__).parent.parent / "tests" / "data" / "sat_data.zarr"
 
     sat = SatelliteDataSource(
+        zarr_path=filename,
+        history_minutes=30,
+        forecast_minutes=60,
+        image_size_pixels=24,
+        meters_per_pixel=6000,
+        channels=("IR_016",),
+    )
+
+    filename = (
+        Path(nowcasting_dataset.__file__).parent.parent / "tests" / "data" / "hrv_sat_data.zarr"
+    )
+    hrvsat = SatelliteDataSource(
         zarr_path=filename,
         history_minutes=30,
         forecast_minutes=60,
@@ -106,8 +118,8 @@ def test_batches():
 
     gsp = GSPDataSource(
         zarr_path=filename,
-        start_dt=datetime(2019, 1, 1),
-        end_dt=datetime(2019, 1, 2),
+        start_dt=datetime(2020, 4, 1),
+        end_dt=datetime(2020, 4, 2),
         history_minutes=30,
         forecast_minutes=60,
         image_size_pixels=64,
@@ -128,7 +140,7 @@ def test_batches():
         manager.local_temp_path = Path(local_temp_path)
 
         # just set satellite as data source
-        manager.data_sources = {"gsp": gsp, "sat": sat}
+        manager.data_sources = {"gsp": gsp, "sat": sat, "hrvsat": hrvsat}
         manager.data_source_which_defines_geospatial_locations = gsp
 
         # make file for locations
@@ -143,6 +155,8 @@ def test_batches():
         assert os.path.exists(f"{dst_path}/train/sat/000000.nc")
         assert os.path.exists(f"{dst_path}/train/gsp/000001.nc")
         assert os.path.exists(f"{dst_path}/train/sat/000001.nc")
+        assert os.path.exists(f"{dst_path}/train/hrvsat/000001.nc")
+        assert os.path.exists(f"{dst_path}/train/hrvsat/000000.nc")
 
 
 def test_save_config():
